SellOMatic_Class = LibStub("AceAddon-3.0"):NewAddon("SellOMatic_Class", "AceEvent-3.0", "AceConsole-3.0");
local SellOMatic = _G.SellOMatic
local item_tooltip = LibStub("LibGratuity-3.0");
local L = LibStub("AceLocale-3.0"):GetLocale("SellOMatic");

local function getOption(info)
	return (info.arg and SellOMatic.db.profile[info.arg] or SellOMatic.db.profile[info[#info]]);
end;

local function setOption(info, value)
	local key = info.arg or info[#info];
	SellOMatic.db.profile[key] = value;
end;

local class_options = {
	type = "group",
	name = L["Class Options"],
	args = {
		class_filter_strict = {
			name = L["Strict Filter"],
			desc = L["Toggles ON/OFF strict class filter"],
			order = 1,
			type = "toggle",
			get = getOption,
			set = setOption,
		},
	},
}

local class_proficiencies = {}
local armor, weapon, class

function SellOMatic_Class:OnInitialize()
	LibStub("AceConfig-3.0"):RegisterOptionsTable("SellOMatic_Class", class_options);
	LibStub("AceConfigDialog-3.0"):AddToBlizOptions("SellOMatic_Class", L["Class Options"], "Sell-O-Matic");
end;

function SellOMatic_Class:OnEnable()
	_, class = UnitClass("player")
	SellOMatic_Class:InitVariables()
end

function SellOMatic_Class:InitVariables()
	armor = select(6,GetItemInfo(1378))
	weapon = select(6,GetItemInfo(2773))
	SellOMatic_Class:PopulateProficencies()
end

function SellOMatic_Class:PopulateProficencies()
	local cloth = select(7,GetItemInfo(1378))
	local leather = select(7,GetItemInfo(1366))
	local mail = select(7,GetItemInfo(2649))
	local plate = select(7,GetItemInfo(7918))
	local shields = select(7,GetItemInfo(2210))
	local relic = select(7,GetItemInfo(23200))
	local bows = select(7,GetItemInfo(2773))
	local crossbows = select(7,GetItemInfo(15807))
	local daggers = select(7,GetItemInfo(2138))
	local guns = select(7,GetItemInfo(2774))
	local fistWeapons = select(7,GetItemInfo(15905))
	local oneHandedAxes = select(7,GetItemInfo(1416))
	local oneHandedMaces = select(7,GetItemInfo(2130))
	local oneHandedSwords = select(7,GetItemInfo(2131))
	local polearms = select(7,GetItemInfo(15810))
	local staves = select(7,GetItemInfo(2132))
	local thrown = select(7,GetItemInfo(28979))
	local twoHandedAxes = select(7,GetItemInfo(1417))
	local twoHandedMaces = select(7,GetItemInfo(2480))
	local twoHandedSwords = select(7,GetItemInfo(1194))
	local wands = select(7,GetItemInfo(5208))
	if SellOMatic.db.profile.class_filter_strict then
		if class == "DEATHKNIGHT" then
			class_proficiencies = { daggers, fistWeapons, staves, bows, crossbows, guns, thrown, wands, shields, cloth, leather }
		elseif class == "DRUID" then
			class_proficiencies = { oneHandedAxes, oneHandedSwords, twoHandedAxes, twoHandedSwords, bows, crossbows, guns, thrown, wands, mail, plate, shields, cloth }
		elseif class == "HUNTER" then
			class_proficiencies = { oneHandedMaces, twoHandedMaces, thrown, wands, plate, shields, relic, cloth }
		elseif class == "MAGE" then
			class_proficiencies = { fistWeapons, oneHandedAxes, oneHandedMaces, polearms, twoHandedAxes, twoHandedMaces, twoHandedSwords, bows, crossbows, guns, thrown, leather, mail, plate, shields, relic }
		elseif class == "PALADIN" then
			class_proficiencies = { daggers, fistWeapons, staves, bows, crossbows, guns, thrown, wands, cloth, leather }
		elseif class == "PRIEST" then
			class_proficiencies = { fistWeapons, oneHandedAxes, oneHandedSwords, polearms, twoHandedAxes, twoHandedMaces, twoHandedSwords, bows, crossbows, guns, thrown, leather, mail, plate, shields, relic }
		elseif class == "ROGUE" then
			class_proficiencies = { polearms, staves, twoHandedAxes, twoHandedMaces, twoHandedSwords, wands, mail, plate, shields, relic, cloth }
		elseif class == "SHAMAN" then
			class_proficiencies = { oneHandedSwords, polearms, twoHandedSwords, bows, crossbows, guns, thrown, wands, plate, cloth }
		elseif class == "WARLOCK" then
			class_proficiencies = { fistWeapons, oneHandedAxes, oneHandedMaces, polearms, twoHandedAxes, twoHandedMaces, twoHandedSwords, bows, crossbows, guns, thrown, leather, mail, plate, shields, relic }
		elseif class == "WARRIOR" then
			class_proficiencies = { wands, relic, cloth, leather }
		end
	else
		if class == "DEATHKNIGHT" then
			class_proficiencies = { daggers, fistWeapons, staves, bows, crossbows, guns, thrown, wands, shields }
		elseif class == "DRUID" then
			class_proficiencies = { oneHandedAxes, oneHandedSwords, twoHandedAxes, twoHandedSwords, bows, crossbows, guns, thrown, wands, mail, plate, shields }
		elseif class == "HUNTER" then
			class_proficiencies = { oneHandedMaces, twoHandedMaces, thrown, wands, plate, shields, relic }
		elseif class == "MAGE" then
			class_proficiencies = { fistWeapons, oneHandedAxes, oneHandedMaces, polearms, twoHandedAxes, twoHandedMaces, twoHandedSwords, bows, crossbows, guns, thrown, leather, mail, plate, shields, relic }
		elseif class == "PALADIN" then
			class_proficiencies = { daggers, fistWeapons, staves, bows, crossbows, guns, thrown, wands }
		elseif class == "PRIEST" then
			class_proficiencies = { fistWeapons, oneHandedAxes, oneHandedSwords, polearms, twoHandedAxes, twoHandedMaces, twoHandedSwords, bows, crossbows, guns, thrown, leather, mail, plate, shields, relic }
		elseif class == "ROGUE" then
			class_proficiencies = { polearms, staves, twoHandedAxes, twoHandedMaces, twoHandedSwords, wands, mail, plate, shields, relic }
		elseif class == "SHAMAN" then
			class_proficiencies = { oneHandedSwords, polearms, twoHandedSwords, bows, crossbows, guns, thrown, wands, plate }
		elseif class == "WARLOCK" then
			class_proficiencies = { fistWeapons, oneHandedAxes, oneHandedMaces, polearms, twoHandedAxes, twoHandedMaces, twoHandedSwords, bows, crossbows, guns, thrown, leather, mail, plate, shields, relic }
		elseif class == "WARRIOR" then
			class_proficiencies = { wands, relic }
		end
	end
end

function SellOMatic:Scan_Class()
	local bag, slot, name, itemName, itemLink, itemRarity, itemSellPrice, itemStackCount, add
	for bag = 0,NUM_BAG_SLOTS,1 do
		for slot = 1, GetContainerNumSlots(bag), 1 do
			add = 0
			name = GetContainerItemLink(bag,slot)
			if name ~= nil then
				itemName, itemLink, _, _, _, itemType, itemSubType, _, itemEquipLoc, _, itemSellPrice = GetItemInfo(name)
				item_tooltip:SetBagItem(bag,slot)
				if itemType == armor or itemType == weapon then
					if itemEquipLoc ~= _G["INVTYPE_CLOAK"] then
						if item_tooltip:Find(ITEM_SOULBOUND,1,3) then
							if SellOMatic_Class:CheckProficiency(itemSubType) == 1 then
								SellOMatic:Add_Shopping_List(itemName, itemLink, 0, 0, itemSellPrice)
							end
						end
					end
				end
			end
		end
	end
end

function SellOMatic_Class:CheckProficiency(itemSubType)
	local x
	for x=1, #class_proficiencies, 1 do
		if class_proficiencies[x] == itemSubType then
			return 1
		end
	end
	return 0
end

function SellOMatic:CheckVariables()
	local x
	local populate = false
	for x=1, #class_proficiencies, 1 do
		if class_proficiencies[x] == nil then
			populate = true
		end
	end
	if armor == nil or weapon == nil then
		populate = true
	end
	if populate then
		SellOMatic_Class:InitVariables()
	end
end
